==> ace_6.0.1.orig.tar.gz: ACE_wrappers/TAO/tests/Param_Test/ub_objref_seq.h <==
// $Id: ub_objref_seq.h 76591 2007-01-25 18:17:52Z elliott_c $

// ============================================================================
//
// = LIBRARY
//    TAO/tests/Param_Test
//
// = FILENAME
//    ub_objref_seq.h
//
// = DESCRIPTION
//     Tests unbounded sequences of object references
//
// = AUTHORS
//      Aniruddha Gokhale
//
// ============================================================================

#ifndef PARAM_TEST_UNBOUNDED_OBJREF_SEQUENCE_H
#define PARAM_TEST_UNBOUNDED_OBJREF_SEQUENCE_H

#include "param_testC.h"

// =*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*
//           test sequence of object references
// =*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*

class Test_ObjRef_Sequence
{
public:
  Test_ObjRef_Sequence (void);
  // ctor

  ~Test_ObjRef_Sequence (void);
  // dtor

  int run_sii_test (Param_Test_ptr objref);
  // run the SII test

  const char *opname (void) const;
  // return operation name

  int init_parameters (Param_Test_ptr objref);
  // set values for parameters

  int reset_parameters (void);
  // reset values for CORBA

  CORBA::Boolean check_validity (void);
  // check if results are valid

  CORBA::Boolean check_validity (CORBA::Request_ptr req);
  // check if results are valid. This is used for DII results

  void print_values (void);
  // print all the values

  void dii_req_invoke (CORBA::Request *);
  // invoke DII request with appropriate exception handling.

protected:
  CORBA::Boolean compare (const Param_Test::Coffee_Mix &s1,
                          const Param_Test::Coffee_Mix &s2);
  // compare

  void print_sequence (const Param_Test::Coffee_Mix &s);
  // print individual sequence
private:
  char *opname_;
  // operation name

  Param_Test::Coffee_Mix in_;
  // in parameter

  // these need memory management
  Param_Test::Coffee_Mix_var inout_;
  // inout parameter

  Param_Test::Coffee_Mix_var out_;
  // out parameter

  Param_Test::Coffee_Mix_var ret_;
  // return value
};

#endif /* PARAM_TEST_UNBOUNDED_OBJREF_SEQUENCE_H */

==> ace_6.5.4.orig.tar.gz: ACE_wrappers/TAO/tests/Param_Test/ub_objref_seq.h <==

//=============================================================================
/**
 *  @file    ub_objref_seq.h
 *
 *   Tests unbounded sequences of object references
 *
 *  @author   Aniruddha Gokhale
 */
//=============================================================================


#ifndef PARAM_TEST_UNBOUNDED_OBJREF_SEQUENCE_H
#define PARAM_TEST_UNBOUNDED_OBJREF_SEQUENCE_H

#include "param_testC.h"

// =*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*
//           test sequence of object references
// =*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*

class Test_ObjRef_Sequence
{
public:
  /// ctor
  Test_ObjRef_Sequence (void);

  /// dtor
  ~Test_ObjRef_Sequence (void);

  /// run the SII test
  int run_sii_test (Param_Test_ptr objref);

  /// return operation name
  const char *opname (void) const;

  /// set values for parameters
  int init_parameters (Param_Test_ptr objref);

  /// reset values for CORBA
  int reset_parameters (void);

  /// check if results are valid
  CORBA::Boolean check_validity (void);

  /// check if results are valid. This is used for DII results
  CORBA::Boolean check_validity (CORBA::Request_ptr req);

  /// print all the values
  void print_values (void);

  /// invoke DII request with appropriate exception handling.
  void dii_req_invoke (CORBA::Request *);

protected:
  /// compare
  CORBA::Boolean compare (const Param_Test::Coffee_Mix &s1,
                          const Param_Test::Coffee_Mix &s2);

  /// print individual sequence
  void print_sequence (const Param_Test::Coffee_Mix &s);
private:
  /// operation name
  char *opname_;

  /// in parameter
  Param_Test::Coffee_Mix in_;

  // these need memory management
  /// inout parameter
  Param_Test::Coffee_Mix_var inout_;

  /// out parameter
  Param_Test::Coffee_Mix_var out_;

  /// return value
  Param_Test::Coffee_Mix_var ret_;
};

#endif /* PARAM_TEST_UNBOUNDED_OBJREF_SEQUENCE_H */
